const swiper = new Swiper('.prod_slider', {
    loop: true,

    // Navigation arrows
    navigation: {
        nextEl: '.prod_next_btn',
        prevEl: '.prod_prev_btn',
    },
    autoplay: {
        delay: 4000,
    },
    breakpoints: {
        480: {
            slidesPerView: 2,
        },
        768: {
            slidesPerView: 3,
        },
        1024: {
            slidesPerView: 4,
        }
    }
});

// Brand slider

const brandSlider = new Swiper('.brand_slider', {
    loop: true,

    // Navigation arrows
    navigation: {
        nextEl: '.brand_next_btn',
        prevEl: '.brand_prev_btn',
    },
    autoplay: {
        delay: 4000,
    },
    breakpoints: {
        300: {
            slidesPerView: 2,
        },
        768: {
            slidesPerView: 3,
        },
        1024: {
            slidesPerView: 5.5,
        }
    }
});

// To top btn

const scrollToTopBtn = document.getElementById('scrollToTopBtn');

window.addEventListener('scroll', function () {
    if (window.scrollY > 100) {
        scrollToTopBtn.style.display = 'block';
    } else {
        scrollToTopBtn.style.display = 'none';
    }
});

scrollToTopBtn.addEventListener('click', function () {
    window.scrollTo({
        top: 0,
        behavior: 'smooth'
    });
});


// Function to animate the counter
function animateCounter(element) {
    const numberElement = element.querySelector('.counter-number');
    const start = parseInt(element.getAttribute('data-start'), 10);
    const end = parseInt(element.getAttribute('data-end'), 10);
    const duration = parseInt(element.getAttribute('data-duration'), 10);
    let current = start;
    const increment = (end - start) / (duration / 20); // Adjust speed with 20ms interval

    const updateCounter = () => {
        current += increment;
        if ((increment > 0 && current >= end) || (increment < 0 && current <= end)) {
            numberElement.textContent = end.toLocaleString() + '+';
        } else {
            numberElement.textContent = Math.floor(current).toLocaleString() + '+';
            setTimeout(updateCounter, 20);
        }
    };

    updateCounter();
}

// Function to handle the Intersection Observer
function createObserver() {
    const options = {
        root: null, // Use the viewport as the root
        threshold: 0.5 // Trigger when 50% of the element is visible
    };

    const observer = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                const counter = entry.target;
                animateCounter(counter);
                observer.unobserve(counter); // Stop observing after animation starts
            }
        });
    }, options);

    // Observe each counter element
    document.querySelectorAll('.counter').forEach(counter => {
        observer.observe(counter);
    });
}

// Initialize the observer when the page loads
window.onload = createObserver;


// Testimonial Slider

const testSlider = new Swiper('.testimonial_slider', {
    loop: true,

    // Navigation arrows
    navigation: {
        nextEl: '.test_next_btn',
        prevEl: '.test_prev_btn',
    },
    pagination: {
        el: '.testimonial_dots',
        clickable:true,
    },
    autoplay: {
        delay: 4000,
    },
    breakpoints: {
        300: {
            slidesPerView: 1,
        },
        768: {
            slidesPerView: 1,
        },
        1024: {
            slidesPerView: 1,
        }
    }
});

document.addEventListener('DOMContentLoaded', function() {
    document.querySelectorAll('.enquiry_btn').forEach(button => {
        button.addEventListener('click', function(event) {
            event.preventDefault(); // Prevents the page from jumping to the top
            
            // Find the nearest product box and retrieve product details
            const productBox = this.closest('.row');
            const productName = productBox.querySelector('.product-name').innerText;
            const productImage = productBox.querySelector('.product-image').src;

            // Construct the WhatsApp URL
            const whatsappURL = `https://wa.me/9216880675?text=${encodeURIComponent(
                `Hello, I am interested in the product: ${productName}. Here is the image link: ${productImage}`
            )}`;

            // Open WhatsApp
            window.open(whatsappURL, '_blank');
        });
    });
});

document.addEventListener("DOMContentLoaded", function () {
    const dropdown = document.getElementById("productsDropdown");

    if (window.innerWidth >= 992) {
        dropdown.removeAttribute("data-bs-toggle");
    }

    window.addEventListener("resize", function () {
        if (window.innerWidth >= 992) {
            dropdown.removeAttribute("data-bs-toggle");
        } else {
            dropdown.setAttribute("data-bs-toggle", "dropdown");
        }
    });
});


document.addEventListener("DOMContentLoaded", function () {
        // Get the current page URL
        const currentPage = window.location.pathname.split("/").pop();

        // Get all nav links
        const navLinks = document.querySelectorAll(".navbar-nav .nav-link");

        // Loop through links and add 'active' class to the matching link
        navLinks.forEach(link => {
            if (link.getAttribute("href") === currentPage) {
                link.classList.add("active");
            }
        });
    });